#!/usr/bin/env python3

# -*- coding: UTF-8 -*-

"""
Description: Launch the script dedicated to find communities
"""


from .community_finder import multiple_community_launcher
import lazyparser as lp
from .config import ConfigGraph
from typing import List
from .install_hipMCL import install_hipmcl
from .sf_and_communities import multiple_stat_launcher
from .nt_and_community import multiple_nt_lmm_launcher
import logging
from ..logging_conf import logging_def


@lp.parse
def launcher(weight: List[int] = (1),
             global_weight: List[int] = (0),
             same_gene: bool = True,
             ps: int = ConfigGraph.cpu,
             html_fig: bool = False, feature: str = 'exon',
             logging_level: str = "DISABLE"):
    """
    Script used to find communities inside  exon co-localized within a project

    :param weight: The weight of interaction to consider (default 1)
    :param global_weight: The global weight to consider. if \
    the global weight is equal to 0 then then density figure are calculated \
    by project, else all project are merge together and the interaction \
    seen in `global_weight` project are taken into account (default 0)
    :param project: The name of the project of interest (default GSM1517081)
    :param same_gene: Say if we consider as co-localised, exons within the \
    same gene (True) or not (False) (default True)
    :param  html_fig: True to display the html figure (default False).
    :param feature: The feature we want to analyse (default 'exon')
    :param logging_level: The level of data to display (default 'DISABLE')
    """
    logging_def(ConfigGraph.community_folder, __file__, logging_level)
    if feature == "gene" and not same_gene:
        logging.warning(f"When level is equal to gene then same_gene must "
                        f"be true. Setting it to True.")
        same_gene = True
    if not ConfigGraph.get_hipmcl_prog().is_file():
        install_hipmcl("INFO")
    multiple_community_launcher(1, weight, global_weight, same_gene, html_fig,
                                feature, logging_level)
    # multiple_stat_launcher(ps, weight, global_weight, same_gene, feature,
    #                        logging_level)
    multiple_nt_lmm_launcher(ps, weight, global_weight, same_gene, feature,
                             logging_level)


launcher()